OneView Driver Support
======================

As the OneView driver requires configuration information to be populated
in the ``ironic.conf`` configuration file that points to the OneView manager
node as well as credentials, bifrost does not support installation and
configuration of the driver. Please reference the
`OneView driver documentation <https://docs.openstack.org/ironic/latest/admin/drivers/oneview.html>`_
for information on configuring of the ``oneview`` driver.
